@@ -1,5 +1,4 @@
 from .function import Function
-from .merge_dicts import merge_dicts
 
 
 class stylize(Function):
@@ -37,11 +36,8 @@ class stylize(Function):
         'bright_white': 67,
     }
 
-    def __init__(self, string, *, modes={}, layers={}, colors={}, **style):
+    def __init__(self, string, **style):
         self.__string = string
-        self.__modes = merge_dicts(self.modes, modes)
-        self.__layers = merge_dicts(self.layers, layers)
-        self.__colors = merge_dicts(self.colors, colors)
         self.__style = style
 
     def __call__(self):
@@ -65,10 +61,10 @@ class stylize(Function):
         offsets = []
         for key, value in self.__style.items():
             try:
-                if key in self.__layers:
-                    offset = self.__layers[key] + self.__colors[value]
+                if key in self.layers:
+                    offset = self.layers[key] + self.colors[value]
                 elif value:
-                    offset = self.__modes[key]
+                    offset = self.modes[key]
             except Exception:
                 raise ValueError(
                     'Bad value "{value}" for key "{key}"'.
