@@ -19,9 +19,6 @@ class stylize_Test(unittest.TestCase):
         result = self.stylize(foreground='red')
         self.assertEqual(result, '[31mtest[m')
 
-    def test_with_modes(self):
-        result = self.stylize(italic=True, modes={'italic': 3})
-        self.assertEqual(result, '[3mtest[m')
 
     def test_with_error(self):
         self.assertRaises(ValueError, self.stylize, error='error')
